@@ -90,7 +90,7 @@ def dict_to_hsd(d, indent=0):
     """
     hsd = ""
     for key, value in d.items():
-        if isinstance(value, collections.Mapping):
+        if isinstance(value, collections.abc.Mapping):
             if "<" in key:
                 key = key.split("<")[0]
             hsd += indent * " " + key + " {\n"
