@@ -15,6 +15,17 @@ properties = {
         "type": "float",
         "units": "hartree",
     },
+    "energy_per_formula_unit": {
+        "calculation": [
+            "energy",
+            "optimization",
+        ],
+        "description": "The energy per empirical formula unit",
+        "dimensionality": "scalar",
+        "methods": [],
+        "type": "float",
+        "units": "hartree",
+    },
     "energy of formation": {
         "calculation": [
             "energy",
@@ -81,6 +92,17 @@ properties = {
         "type": "float",
         "units": "hartree",
     },
+    "dipole_moments": {
+        "calculation": [
+            "energy",
+            "optimization",
+        ],
+        "description": "The dipole moments of the system",
+        "dimensionality": [3, "nspins"],
+        "methods": [],
+        "type": "float",
+        "units": "",
+    },
     "eigenvalues": {
         "calculation": [
             "energy",
@@ -166,6 +188,50 @@ properties = {
         "type": "float",
         "units": "Å^3",
     },
+    "#_primitive_cells": {
+        "calculation": [
+            "energy",
+            "optimization",
+        ],
+        "description": "The number of primitive cells in the unit cell",
+        "dimensionality": "scalar",
+        "methods": [],
+        "type": "integer",
+        "units": "",
+    },
+    "Z": {
+        "calculation": [
+            "energy",
+            "optimization",
+        ],
+        "description": "The number of empirical formula u its in the system",
+        "dimensionality": "scalar",
+        "methods": [],
+        "type": "integer",
+        "units": "",
+    },
+    "formula": {
+        "calculation": [
+            "energy",
+            "optimization",
+        ],
+        "description": "The chemical formula of the system",
+        "dimensionality": "scalar",
+        "methods": [],
+        "type": "string",
+        "units": "",
+    },
+    "empirical_formula": {
+        "calculation": [
+            "energy",
+            "optimization",
+        ],
+        "description": "The empirical formula of the system",
+        "dimensionality": "scalar",
+        "methods": [],
+        "type": "string",
+        "units": "",
+    },
     "cell_volume": {
         "calculation": [
             "energy",
